@@ -1,5 +1,18 @@
 package App::Ack::Filter::IsPathGroup;
 
+
+=head1 NAME
+
+App::Ack::Filter::IsPathGroup
+
+=head1 DESCRIPTION
+
+The App::Ack::Filter::IsPathGroup class optimizes multiple ::IsPath
+calls into one container.  See App::Ack::Filter::IsGroup for details.
+
+=cut
+
+
 use strict;
 use warnings;
 use base 'App::Ack::Filter';
