@@ -1,5 +1,16 @@
 package App::Ack::Filter::MatchGroup;
 
+=head1 NAME
+
+App::Ack::Filter::MatchGroup
+
+=head1 DESCRIPTION
+
+The App::Ack::Filter::MatchGroup class optimizes multiple ::Match calls
+into one container.  See App::Ack::Filter::IsGroup for details.
+
+=cut
+
 use strict;
 use warnings;
 use base 'App::Ack::Filter';
@@ -34,10 +45,14 @@ sub filter {
 
 sub inspect {
     my ( $self ) = @_;
+
+    # XXX Needs an explicit return.
 }
 
 sub to_string {
     my ( $self ) = @_;
+
+    # XXX Needs an explicit return.
 }
 
 1;
